==> react-pose-1.5.1.tgz: package/src/posed.tsx <==
import * as React from 'react';
import { ReactElement } from 'react';
import { PoseElement, PoseParentContext } from './components/PoseElement';
import {
  PoseElementProps,
  PoseContextProps
} from './components/PoseElement.types';
import { PoserProps } from 'popmotion-pose';

// TODO: Something is wrong with the TypeScript React bindings here,
// I've had to typecast a component as a Component a couple times now.
const PoseElementComponent = PoseElement as React.PureComponent;

export type ComponentFactory = (
  poseProps?: PoserProps
) => (props: PoseElementProps) => ReactElement<any>;

export type Posed = {
  (): ComponentFactory;
  [key: string]: ComponentFactory;
};

const componentCache = new Map<string, ComponentFactory>();

const createComponentFactory = (key: string) => {
  const componentFactory: ComponentFactory = (poseProps = {}) => ({
    withParent = true,
    ...props
  }) =>
    !withParent || props.parentValues ? (
      <PoseElementComponent
        poseProps={poseProps}
        elementType={key}
        {...props}
      />
    ) : (
      <PoseParentContext.Consumer>
        {(parentCtx: PoseContextProps) => (
          <PoseElementComponent
            poseProps={poseProps}
            elementType={key}
            {...props}
            {...parentCtx}
          />
        )}
      </PoseParentContext.Consumer>
    );

  componentCache.set(key, componentFactory);

  return componentFactory;
};

const getComponentFactory = (key: string) =>
  componentCache.has(key)
    ? componentCache.get(key)
    : createComponentFactory(key);

const posed: Posed = new Proxy(
  function() {} as Posed,
  {
    get: (target, key: string) => getComponentFactory(key),
    apply: (target, thisArg, argumentsList) => getComponentFactory(argumentsList[0]),
  }
);

export default posed;

==> react-pose-1.6.1.tgz: package/src/posed.tsx <==
import * as React from 'react';
import { ReactElement } from 'react';
import { PoseElement, PoseParentContext } from './components/PoseElement';
import {
  PoseElementProps,
  PoseContextProps
} from './components/PoseElement.types';
import { DomPopmotionConfig } from 'popmotion-pose/lib/types';

// TODO: Something is wrong with the TypeScript React bindings here,
// I've had to typecast a component as a Component a couple times now.
const PoseElementComponent = PoseElement as React.PureComponent;

export type ComponentFactory = (
  poseConfig?: DomPopmotionConfig
) => (props: PoseElementProps) => ReactElement<any>;

export type Posed = {
  (): ComponentFactory;
  [key: string]: ComponentFactory;
};

const componentCache = new Map<string, ComponentFactory>();

const createComponentFactory = (key: string) => {
  const componentFactory: ComponentFactory = (poseConfig = {}) => ({
    withParent = true,
    ...props
  }) =>
    !withParent || props.parentValues ? (
      <PoseElementComponent
        poseConfig={poseConfig}
        elementType={key}
        {...props}
      />
    ) : (
      <PoseParentContext.Consumer>
        {(parentCtx: PoseContextProps) => (
          <PoseElementComponent
            poseConfig={poseConfig}
            elementType={key}
            {...props}
            {...parentCtx}
          />
        )}
      </PoseParentContext.Consumer>
    );

  componentCache.set(key, componentFactory);

  return componentFactory;
};

const getComponentFactory = (key: string) =>
  componentCache.has(key)
    ? componentCache.get(key)
    : createComponentFactory(key);

const posed: Posed = new Proxy(function() {} as Posed, {
  get: (target, key: string) => getComponentFactory(key),
  apply: (target, thisArg, argumentsList) =>
    getComponentFactory(argumentsList[0])
});

export default posed;
